CodeMirror: FAQ

# { } CodeMirror

    /* Frequently asked
       questions */

## Q: Can I use CodeMirror in my such-and-such project?

A: Yes. The license is short, simple, and permissive.

## Q: You said you fixed this-and-this issue, but I'm still seeing it.

A: One possibility is that I screwed up, but a very real alternative is that you're looking at a cached version of the CodeMirror scripts. Because the scripts are loaded into an iframe, the ctrl-f5 you issued on the outer page doesn't always cause them to be reloaded (IE, Opera, and Firefox are the worst offenders here). Clear your cache and re-try.

## Q: I can't put content containing `</textarea>` into CodeMirror!

A: [Web-programming 101] The first `</textarea>` following a `<textarea>` tag will close the textarea. This has nothing to do with CodeMirror. Sit down, and spend ten minutes thinking about why HTML-escaping was invented.

## Q: I have this huge chunk of code that does not work, can you debug it for me?

A: Nope. If you can't be bothered isolate your problem in 20 lines of code or less, I can't be bothered to think about it.

## Q: How do I submit patches for CodeMirror?

A: Preferred way is to create a fork on github, add your patch, and send me a pull request. Diffs (against the latest version!) by mail are also cool.

## Questions

- Licensing
- Cache Issues
- `<textarea>`
- Code Questions
- Submitting Patches

## Site

- Front Page
- User Manual
- Google Group
- Compression Helper
- War Story